@@ -8,7 +8,7 @@ use HTTP::Request();
 use JSON::XS();
 use Encode qw(decode_utf8);
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use constant {
     ONE_REQ     => 1,
@@ -498,6 +498,21 @@ sub mapping {
     );
 }
 
+#===================================
+sub update_index_settings {
+#===================================
+    my ( $self, $params ) = &_params;
+    $self->_do_action(
+        'update_settings',
+        {   method  => 'PUT',
+            cmd     => CMD_index,
+            postfix => '_settings',
+            data => { index => 'settings'}
+        },
+        $params
+    );
+}
+
 #===================================
 sub cluster_state {
 #===================================
@@ -1150,10 +1165,10 @@ ElasticSearch - An API for communicating with ElasticSearch
 
 =head1 VERSION
 
-Version 0.19, tested against ElasticSearch server version 0.9.1.
+Version 0.20, tested against ElasticSearch server version 0.10.0.
 
 NOTE: Various features present in older versions of the ElasticSearch server
-which have been removed from ElasticSearch 0.9.0 have also been removed from
+which have been removed from ElasticSearch 0.10.0 have also been removed from
 this module.  If you are still using ElasticSearch 0.8.0 or older (and I highly
 recommned upgrading!), then you should use ElasticSearch.pm version 0.16.
 
@@ -1468,7 +1483,7 @@ If a search has been executed with a C<scroll> parameter, then the returned
 C<scroll_id> can be used like a cursor to scroll through the rest of the
 results.
 
-Note - this doesn't seem to work correctly in version 0.9.1 of ElasticSearch.
+Note - this doesn't seem to work correctly in version 0.10.1 of ElasticSearch.
 
 See L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/search/#Scrolling>
 
@@ -1655,6 +1670,22 @@ Deletes an existing index, or throws an exception if the index doesn't exist, eg
 
 See L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/admin/indices/delete_index>
 
+=head3 C<update_index_settings()>
+
+    $result = $e->update_index_settings(
+        index       => multi,
+        settings    => { ... settings ...}
+    );
+
+Update the settings for all, one or many indices.  Currently only the
+C<number_of_replicas> is exposed:
+
+    $result = $e->update_index_settings(
+        settings    => {  number_of_replicas => 1 }
+    );
+
+See L<http://www.elasticsearch.com/docs/elasticsearch/rest_api/admin/indices/update_settings/>
+
 =head3 C<aliases()>
 
     $result = $e->aliases( actions => [actions] | {actions} )
@@ -2143,7 +2174,7 @@ Any documents indexed via this module will be not susceptible to this problem.
 
 =item L</"scroll()">
 
-C<scroll()> is broken in version 0.9.1 and earlier versions of ElasticSearch.
+C<scroll()> is broken in version 0.10.1 and earlier versions of ElasticSearch.
 
 See L<http://github.com/elasticsearch/elasticsearch/issues/issue/136>
 
